@@ -1,8 +1,8 @@
 import unittest
 import os
 import numpy as np
-from pyinterpolate.data_processing.data_preparation.read_data import read_point_data
-from pyinterpolate.calculations.distances.calculate_distances import calc_point_to_point_distance
+from pyinterpolate.io.read_data import read_point_data
+from pyinterpolate.distance.calculate_distances import calc_point_to_point_distance
 from pyinterpolate.semivariance.semivariogram_estimation.calculate_covariance import calculate_covariance
 
 
@@ -10,7 +10,7 @@ class TestCalculateCovariance(unittest.TestCase):
 
     def test_calculate_covariance(self):
         my_dir = os.path.dirname(__file__)
-        path = os.path.join(my_dir, 'sample_data/poland_dem_gorzow_wielkopolski')
+        path = os.path.join(my_dir, '../sample_data/poland_dem_gorzow_wielkopolski')
 
         dataset = read_point_data(path, 'txt')
 
